Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authordiosmosis <benaka@piwik.pro>2015-03-07 04:38:24 +0300
committerdiosmosis <benaka@piwik.pro>2015-03-07 04:38:24 +0300
commite2cfb6128db69cb04209e3dedd01bae79009fa7e (patch)
tree2374c2eba3d33a8f27fb42df45a012c414a15a81 /misc/others
parentdd88afa60014b2fc23f11cce1146d34b55264919 (diff)
parent71cacb0aca6aeb557e536c2b5b5b687f58f5465f (diff)
Merge branch 'master' into geo-attribution-task
Conflicts: misc/others/geoipUpdateRows.php
Diffstat (limited to 'misc/others')
-rw-r--r--misc/others/api_internal_call.php2
-rw-r--r--misc/others/cli-script-bootstrap.php31
-rw-r--r--misc/others/uninstall-delete-piwik-directory.php9
3 files changed, 21 insertions, 21 deletions
diff --git a/misc/others/api_internal_call.php b/misc/others/api_internal_call.php
index f099b962ee..4cc0052911 100644
--- a/misc/others/api_internal_call.php
+++ b/misc/others/api_internal_call.php
@@ -18,7 +18,7 @@ FrontController::getInstance()->init();
// This inits the API Request with the specified parameters
$request = new Request('
module=API
- &method=UserSettings.getResolution
+ &method=Resolution.getResolution
&idSite=7
&date=yesterday
&period=week
diff --git a/misc/others/cli-script-bootstrap.php b/misc/others/cli-script-bootstrap.php
index f26d45abcc..afd3494834 100644
--- a/misc/others/cli-script-bootstrap.php
+++ b/misc/others/cli-script-bootstrap.php
@@ -4,37 +4,34 @@
*
* @link http://piwik.org
* @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- *
*/
-use Piwik\Config;
-use Piwik\FrontController;
-error_reporting(E_ALL | E_NOTICE);
+use Piwik\Container\StaticContainer;
+use Piwik\FrontController;
+use Symfony\Bridge\Monolog\Handler\ConsoleHandler;
+use Symfony\Component\Console\Output\ConsoleOutput;
define('PIWIK_DOCUMENT_ROOT', dirname(__FILE__) == '/' ? '' : dirname(__FILE__) . '/../..');
if (file_exists(PIWIK_DOCUMENT_ROOT . '/bootstrap.php')) {
require_once PIWIK_DOCUMENT_ROOT . '/bootstrap.php';
}
-if (!defined('PIWIK_USER_PATH')) {
- define('PIWIK_USER_PATH', PIWIK_DOCUMENT_ROOT);
-}
if (!defined('PIWIK_INCLUDE_PATH')) {
define('PIWIK_INCLUDE_PATH', PIWIK_DOCUMENT_ROOT);
}
+require_once PIWIK_INCLUDE_PATH . '/core/bootstrap.php';
+
ignore_user_abort(true);
set_time_limit(0);
-@date_default_timezone_set('UTC');
-
-require_once PIWIK_INCLUDE_PATH . '/libs/upgradephp/upgrade.php';
-require_once PIWIK_INCLUDE_PATH . '/core/testMinimumPhpVersion.php';
-require_once PIWIK_INCLUDE_PATH . '/core/Loader.php';
-\Piwik\Loader::init();
$GLOBALS['PIWIK_TRACKER_DEBUG'] = false;
define('PIWIK_ENABLE_DISPATCH', false);
-Config::getInstance()->log['log_writers'][] = 'screen';
-Config::getInstance()->log['log_level'] = 'VERBOSE';
-Config::getInstance()->log['string_message_format'] = "%message%";
-FrontController::getInstance()->init(); \ No newline at end of file
+if (Piwik\Common::isPhpCliMode()) {
+ StaticContainer::setEnvironment('cli');
+ /** @var ConsoleHandler $consoleLogHandler */
+ $consoleLogHandler = StaticContainer::get('Symfony\Bridge\Monolog\Handler\ConsoleHandler');
+ $consoleLogHandler->setOutput(new ConsoleOutput());
+}
+
+FrontController::getInstance()->init();
diff --git a/misc/others/uninstall-delete-piwik-directory.php b/misc/others/uninstall-delete-piwik-directory.php
index 97030daa48..ac606bb721 100644
--- a/misc/others/uninstall-delete-piwik-directory.php
+++ b/misc/others/uninstall-delete-piwik-directory.php
@@ -1,10 +1,13 @@
<?php
+exit; // Remove this line before using the script
+
// How to remove the piwik/ directory if it does not work in FTP?
// 1) Download and upload this file to your webserver
// 2) Put this file in the folder that contains the piwik/ directory (above the piwik/ directory)
// For example if the piwik/ folder is at http://your-site/piwik/ you put the file in http://your-site/uninstall-delete-piwik-directory.php
-// 3) Go with your browser to http://your-site/uninstall-delete-piwik-directory.php
-// 4) The folder http://your-site/piwik/ should now be deleted!
+// 4) Go with your browser to http://your-site/uninstall-delete-piwik-directory.php
+// 5) The folder http://your-site/piwik/ should now be deleted!
// We hope you enjoyed Piwik. If you have any feedback why you stopped using Piwik,
// please let us know at hello@piwik.org - we are interested by your experience
function unlinkRecursive($dir)
@@ -1,10 +1,13 @@
// How to remove the piwik/ directory if it does not work in FTP?
// 1) Download and upload this file to your webserver
-// 2) Put this file in the folder that contains the piwik/ directory (above the piwik/ directory)
+// 2) Remove the 2nd line (the "exit;")
+// 3) Put this file in the folder that contains the piwik/ directory (above the piwik/ directory)
// For example if the piwik/ folder is at http://your-site/piwik/ you put the file in http://your-site/uninstall-delete-piwik-directory.php